==> provider_software_3.8.1.tar.gz: provider_software_3.8.1/lib/biocase/wrapper/dbmod/dbmod_pymssql.py <==
# -*- coding: utf8 -*-
'''
DB MODULE - ODBC for TSQL
*******************************
***  DB MODULE - ODBC for TSQL
*******************************
$RCSfile: dbmod_odbc_tsql.py,v $
$Revision: 1631 $
$Author: j.holetschek $
$Date: 2021-05-26 11:20:44 +0200 (Mi, 26. Mai 2021) $

A native biocase.wrapper database module to access MS SQL Server databases.
Based on pymssql
'''

from biocase.wrapper.sql.base import sqlBase
from biocase.wrapper.dbmod.dbmod_odbc_tsql import DBmodule
from biocase.wrapper.errorclasses import DbModuleMissingError, ConnectionError

import logging
log = logging.getLogger("pywrapper.dbmod")


class DBmodule(DBmodule):
    __dbmod__ = 'MS SQL Server ODBC module using pymssql'

    def createDBconnection(self):
        try:
            import pymssql
        except:
            raise DbModuleMissingError('pymssql')

        self.__class__.__version__ = pymssql.__version__

        try:
            con = pymssql.connect(host=self.psfObj.dbIP, user=self.psfObj.user, password=self.psfObj.password, database=self.psfObj.database)

            # Try to get SQL Server version and turn on ROWS/OFFSET syntax
            try:
                c = con.cursor()
                c.execute("SELECT cast(SERVERPROPERTY('ProductVersion') as varchar)")
                ver = c.fetchone()[0]
                self.__class__.__version__ += " (SQL Server version %s)" % ver
                if int(ver[:2]) >= 11:
                    log.info("SQL Server version 2012+ found (%s); using ROWS/OFFSET syntax for selects." % ver)
                    sqlBase.templates['select-limit-offset'] = 'SELECT DISTINCT #1 FROM #2 OFFSET #4 ROWS FETCH NEXT #3 ROWS ONLY'
                c.close()
            except:
                log.warn("Retrieval of SQL Server version failed; using standard syntax.")

        except Exception as ex:
            log.exception(ex)
            raise ConnectionError()

        # Last, return connection
        return con

==> provider_software_3.8.4.tar.gz: provider_software_3.8.4/lib/biocase/wrapper/dbmod/dbmod_pymssql.py <==
# -*- coding: utf8 -*-
'''
DB MODULE - ODBC for TSQL
*******************************
***  DB MODULE - ODBC for TSQL
*******************************
$RCSfile: dbmod_odbc_tsql.py,v $
$Revision: 1683 $
$Author: j.holetschek $
$Date: 2023-08-18 13:59:25 +0200 (Fr, 18. Aug 2023) $

A native biocase.wrapper database module to access MS SQL Server databases.
Based on pymssql
'''

from biocase.wrapper.sql.base import sqlBase
from biocase.wrapper.dbmod.dbmod_odbc_tsql import DBmodule as DBmod
from biocase.wrapper.errorclasses import DbModuleMissingError, ConnectionError

import logging
log = logging.getLogger("pywrapper.dbmod")


class DBmodule(DBmod):
    __dbmod__ = 'MS SQL Server ODBC module using pymssql'

    def __init__(self, psfObj):
        DBmod.__init__(self, psfObj)
        self.trans.parameterPlaceholder = '%s'

    def createDBconnection(self):
        try:
            import pymssql
        except:
            raise DbModuleMissingError('pymssql')

        self.__class__.__version__ = pymssql.__version__

        try:
            con = pymssql.connect(host=self.psfObj.dbIP, user=self.psfObj.user, password=self.psfObj.password, database=self.psfObj.database)

            # Try to get SQL Server version and turn on ROWS/OFFSET syntax
            try:
                c = con.cursor()
                c.execute("SELECT cast(SERVERPROPERTY('ProductVersion') as varchar)")
                ver = c.fetchone()[0]
                self.__class__.__version__ += " (SQL Server version %s)" % ver
                if int(ver[:2]) >= 11:
                    log.info("SQL Server version 2012+ found (%s); using ROWS/OFFSET syntax for selects." % ver)
                    sqlBase.templates['select-limit-offset'] = 'SELECT DISTINCT #1 FROM #2 OFFSET #4 ROWS FETCH NEXT #3 ROWS ONLY'
                c.close()
            except:
                log.warn("Retrieval of SQL Server version failed; using standard syntax.")

        except Exception as ex:
            log.exception(ex)
            raise ConnectionError()

        # Last, return connection
        return con
